/**
 * Class representing a reference to a {@link ResultSetRow} in the result of a {@link RQLQuery}.
 *
 * Use this to resolve a {@link ResultSetRow} of the referenced {@link RQLQuery}
 * from a {@link TransactionResult}.
 *
 * @category Api
 */
export class RQLQueryRowRef {
  constructor(public readonly queryUUID: string, public readonly row: number) {}

  /**
   * Retrieve a reference to the given column in this row.
   *
   * @param c The column to get a reference for
   * @returns A reference to the given column in the current row
   *
   * @category Api
   */
  column(c: number | string): RQLQueryCellRef {
    return new RQLQueryCellRef(this.queryUUID, this.row, c);
  }
}

/**
 * Class representing a reference to a {@link ResultSetCell} in the result of a {@link RQLQuery}.
 *
 * Use this to resolve a {@link ResultSetCell} of the referenced {@link RQLQuery}
 * from a {@link TransactionResult}.
 *
 * This reference can also be used in parameters of other {@link RQLQuery}.
 * If both {@link RQLQuery} are used in the same {@link RQLQuery},
 * then the resolved value from the first query will be used in the second.
 *
 * @category Api
 */
export class RQLQueryCellRef {
  constructor(
    public readonly queryUUID: string,
    public readonly row: number,
    public readonly column: number | string
  ) {}
}
