# CubicwebJS demo

This package provides a simple demo to test the different cubicwebjs packages.

Go to [`cubicweb-demojs/cubicweb_demojs/schema.py`](cubicweb-demojs/cubicweb_demojs/schema.py) to inspect the demo schema.

## Installation

To run the demo, you need to install both the cubicweb instance and the frontend.

### Cubicweb instance

A demo cube to create your instance is provided in the folder `cubicweb_demojs`. Follow these steps to install it.

```sh
# Create a venv and install the cube
cd cubicweb-demojs
python -m venv venv
source venv/bin/activate
pip install -e .

# Create a new instance from the cube
# During the setup, choose sqlite, set admin login and password to "admin" and enable anonymous access.
# Leave everything to defaults.
cubicweb-ctl create demojs demojs 

```
Enable login routes by editing `~/etc/cubicweb.d/demojs/pyramid.ini` and adding the following line to `cubicweb.includes` list:

```ini
  cubicweb_api.auth.routes
```

Allow the frontend to send requests to the instance by setting the relevant
options in `~/etc/cubicweb.d/demojs/all-in-one.conf`:

```ini
access-control-allow-origin=http://localhost:3000
access-control-allow-headers=x-client-name,content-type
```

#### Testing with cube SignedRequest

If you want to run the demo with the signed request cube installed.
First install the `cubicweb-signedrequest` python package:

```sh
pip install cubicweb-signedrequest
```
Then migrate the instance to use the newly installed cube.

```sh
echo 'add_cube("signedrequest")' | cubicweb-ctl shell demojs
```

Create a token for the admin user.

```sh
echo 'create_entity("AuthToken", token_for_user=find("CWUser", login="admin").one(), id="demo-token", enabled=True); commit()' | cubicweb-ctl shell demojs
```

Get the newly created token.

```sh
echo 'find("AuthToken", id="demo-token").one().token' | cubicweb-ctl shell demojs
```

Ensure that headers used by the SignedRequest protocol are allowed by backend.

```ini 
access-control-allow-headers=x-client-name,content-type,authorization,content-sha512,x-cubicweb-date
```


### Frontend

The frontend is a simple node application. Follow these steps to install it.

```sh
yarn install --immutable
```

## Run

In one terminal, run you backend instance.

```sh
yarn start-cubicweb
```

In another, run the frontend.

```sh
yarn start
```

when using the cube `signedrequest`, provide the token retrieved in previous section:

```sh
REACT_APP_SIGNEDREQUEST_TOKEN='TOKEN' yarn start
```

Navigate to [http://localhost:3000](http://localhost:3000) to access the frontend.
