export type CubicWebErrorData = {
  field: string;
  message: string;
};

// update regex pattern when errorString has new pattern detected
// below some lignes of texts validation with results of group 1-2.
// ex1 = 12306:
// ex2 = * scheduled_task_of: Réseau appartient à une contrainte d'unicité transgressée
// ex3 = 12307 (frequency): Le format de l'intervalle de temps est invalide
// ex4 = * : certaines relations transgressent une contrainte d'unicité
// matches group 1 : 6 | scheduled_task_of | (frequency) | void
// matches group 2 : void | Réseau appartient à une contrainte d'unicité transgressée | Le format de l'intervalle de temps est invalide | certaines relations transgressent une contrainte d'unicité
const REGEX_PATTERN = /^(?:\*|\d+)\s?([^:]+): (.*)/;

// function too get cubicWeb Error Data message string on format CubicWebErrorData
// because cubicweb returns simple strings of characters that must be parsed to retrieve the information
export function getCubicWebErrorData(
  errorString?: string
): CubicWebErrorData[] {
  const cubicWebErrorDataList: CubicWebErrorData[] = [];

  errorString?.split("\n").forEach((subErrorString) => {
    const matches = subErrorString.match(REGEX_PATTERN);

    if (matches) {
      cubicWebErrorDataList.push({
        // Relations have a prefix to indicate their role
        // We must remove it to be compatible with forms
        field: matches[1]
          .replace("(", "")
          .replace(")", "")
          .replace("-subject", "")
          .replace("-object", "")
          .trim(),
        message: matches[2],
      });
    }
  });

  return cubicWebErrorDataList;
}

export function getErrorMessages(
  cubicWebErrorDataList: CubicWebErrorData[],
  availableRelations: string[]
): {
  localErrorList: CubicWebErrorData[];
  globalErrorList: CubicWebErrorData[];
} {
  const localErrorList: CubicWebErrorData[] = [];
  const globalErrorList: CubicWebErrorData[] = [];

  cubicWebErrorDataList.forEach((errorData) => {
    if (availableRelations.includes(errorData.field)) {
      localErrorList.push(errorData);
    } else {
      globalErrorList.push(errorData);
    }
  });

  return {
    localErrorList,
    globalErrorList,
  };
}
