import { generateDeleteEntitiesRQL } from "../delete";
import { mockBlogSchema } from "../utils/test_utils";

describe("generateDeleteEntitiesRQL", () => {
  it("Generates a transaction with one query", () => {
    const queries = generateDeleteEntitiesRQL(mockBlogSchema, "Blog", {
      where: { eid: 5 },
    });
    expect(queries).toHaveLength(1);
  });

  it("Generates a transaction with the right RQL and params", () => {
    const queries = generateDeleteEntitiesRQL(mockBlogSchema, "Blog", {
      where: { eid: 5 },
    });
    expect(queries[0].rql).toBe("DELETE Blog X WHERE X eid %(eid)s");
    expect(queries[0].params).toMatchObject({
      eid: 5,
    });
  });
  it("Generates a transaction with one query", () => {
    const queries = generateDeleteEntitiesRQL(mockBlogSchema, "Blog", {
      where: {
        eid: [5, 6],
      },
    });
    expect(queries).toHaveLength(1);
  });
  it("Throws an error with an unknown relation", () => {
    expect(() =>
      generateDeleteEntitiesRQL(mockBlogSchema, "Blog", { where: { foo: 5 } })
    ).toThrowError("No valid restrictions found");
  });
  it("Generates a transaction with the right RQL and params for one eid", () => {
    const queries = generateDeleteEntitiesRQL(mockBlogSchema, "Blog", {
      where: { eid: 5 },
    });
    expect(queries[0].rql).toBe("DELETE Blog X WHERE X eid %(eid)s");
    expect(queries[0].params).toMatchObject({});
  });
  it("Generates a transaction with the right RQL and params for several eid", () => {
    const queries = generateDeleteEntitiesRQL(mockBlogSchema, "Blog", {
      where: { eid: [5, 6] },
    });
    expect(queries[0].rql).toBe("DELETE Blog X WHERE X eid IN (5, 6,)");
    expect(queries[0].params).toMatchObject({});
  });
});
