import { rowToEntity } from "../../utils/resultset.js";
import { ResultSetRow, getLooseSchema } from "@cubicweb/client";
import {
  BLOG_ENTRY_ATTRIBUTES,
  BLOG_ENTRY_SUBJECTS,
  mockBlogSchema,
} from "../../utils/test_utils.js";

describe("rowToRecord", () => {
  const blogEntryEntity =
    getLooseSchema(mockBlogSchema).getEntity("BlogEntry")!;
  const blogEntity = getLooseSchema(mockBlogSchema).getEntity("Blog")!;

  it("should return an empty object", () => {
    expect(rowToEntity(new ResultSetRow([], []), [], [], [])).toMatchObject({});
  });

  describe("handling data", () => {
    it("should handle attributes", () => {
      expect(
        rowToEntity(
          new ResultSetRow(
            [],
            [0, "test_content", "test_content_format", "test_title"]
          ),
          BLOG_ENTRY_ATTRIBUTES,
          [],
          []
        )
      ).toMatchObject({
        eid: 0,
        content: "test_content",
        content_format: "test_content_format",
        title: "test_title",
      });
    });
    it("should handle subject relations", () => {
      expect(
        rowToEntity(
          new ResultSetRow([], [0, "5, 2", "1"]),
          [],
          BLOG_ENTRY_SUBJECTS,
          []
        )
      ).toMatchObject({
        eid: 0,
        creator: [5, 2],
        entry_of: [1],
      });
    });
    it("should handle object relations", () => {
      expect(
        rowToEntity(
          new ResultSetRow([], [0, "1"]),
          [],
          [],
          blogEntity.relationDefinitions.object
        )
      ).toMatchObject({
        eid: 0,
        reverse_entry_of: [1],
      });
    });
    it("should detect arrays of different lengths", () => {
      expect(() =>
        rowToEntity(
          new ResultSetRow([], [0, "test"]),
          blogEntryEntity.attributes,
          [],
          []
        )
      ).toThrow();
    });
  });
});
