import { EntitySchema } from "@cubicweb/client";
import { EntityData } from "./types.js";
import { getEntityRelationNames } from "./schema.js";

export function splitEntityData(
  entitySchema: EntitySchema,
  entityData: EntityData
): {
  attributes: EntityData;
  subjects: EntityData;
  objects: EntityData;
} {
  const validAttributes = getEntityRelationNames(entitySchema, "attributes");
  const validSubjectRelations = getEntityRelationNames(entitySchema, "subject");
  const validObjectRelations = getEntityRelationNames(entitySchema, "object");

  const attributes: EntityData = {};
  const subjects: EntityData = {};
  const objects: EntityData = {};

  Object.entries(entityData).forEach(([key, value]) => {
    if (validAttributes.includes(key)) {
      attributes[key] = value;
    } else if (validSubjectRelations.includes(key)) {
      subjects[key] = value;
    } else if (validObjectRelations.includes(key)) {
      objects[key] = value;
    } else {
      throw new Error(
        `${key} does not exist in entity type ${entitySchema.type}`
      );
    }
  });

  return {
    attributes: attributes,
    subjects: subjects,
    objects: objects,
  };
}
